#
#  Copyright 1999-2001 Illinois Institute of Technology
#
#  See the file "LICENSE" for information on usage and redistribution
#  of this file, and for a DISCLAIMER OF ALL WARRANTIES.
#

proc create_optimize_gui { record_list } {
	frame .title
	pack .title -before .message_log
	
	label .title.text -text "Sector 17 Beamline Optimization"
	pack .title.text
	
	#-----------------------------------------------------------

	set statuswidth 30
	
	frame .sep1 -height 2 -borderwidth 1 -relief sunken
	pack .sep1 -expand yes -fill x -pady 5 -before .message_log
	
	frame .main
	pack .main -padx 10 -before .message_log
	
	set row 0
	
	label .main.mono_header -text Monochromator
	label .main.blank_header 
	label .main.old_header -text "Old Position"
	label .main.new_header -text "New Position"
	
	grid .main.mono_header .main.blank_header \
		.main.old_header .main.new_header -sticky w
	
	incr row

	set omega [ $record_list get_record "omega" ]

	set thisfield .main.omega
	
	button ${thisfield}_button -text "Optimize Omega" -background limegreen -command \
			[ code optimize_omega $record_list $omega $thisfield ]
	
	label ${thisfield}_status -width $statuswidth -text "Not Yet Optimized"
	
	label ${thisfield}_old_position -text [ optimize_get_position $omega ]
	label ${thisfield}_new_position -text "---"
	
	grid ${thisfield}_button       -row $row -column 0 -sticky w
	grid ${thisfield}_status       -row $row -column 1 -sticky w
	grid ${thisfield}_old_position -row $row -column 2 -sticky e
	grid ${thisfield}_new_position -row $row -column 3 -sticky e
	
	incr row

	set chi [ $record_list get_record "chi" ]

	set thisfield .main.chi
	
	button ${thisfield}_button -text "Optimize Chi" -background limegreen -command \
			[ code optimize_chi $record_list $chi $thisfield ]
	
	label ${thisfield}_status -width $statuswidth -text "Not Yet Optimized"
	
	label ${thisfield}_old_position -text [ optimize_get_position $chi ]
	label .main.chi_new_position -text "---"
	
	grid ${thisfield}_button       -row $row -column 0 -sticky w
	grid ${thisfield}_status       -row $row -column 1 -sticky w
	grid ${thisfield}_old_position -row $row -column 2 -sticky e
	grid ${thisfield}_new_position -row $row -column 3 -sticky e
	
	incr row
	
	#-----------------------------------------------------------
	
	label .main.blank2
	grid .main.blank2
	
	incr row
	
	label .main.mirror -text Mirror
	grid .main.mirror -sticky w
	
	incr row

	if { $MxOptimize::beamline_name == "imca17id" } {
		set vert_mirror [ $record_list get_record "vmirror_z" ]
	} else {
		set vert_mirror [ $record_list get_record "mjack_vert" ]
	}

	set thisfield .main.vert_mirror
	
	button ${thisfield}_button -text "Optimize Vertical" -background limegreen -command \
	    [ code optimize_vert_mirror $record_list $vert_mirror $thisfield ]
	
	label ${thisfield}_status -width $statuswidth -text "Not Yet Optimized"
	
	label ${thisfield}_old_position -text \
		[ optimize_get_position $vert_mirror ]

	label ${thisfield}_new_position -text "---"
	
	grid ${thisfield}_button       -row $row -column 0 -sticky w
	grid ${thisfield}_status       -row $row -column 1 -sticky w
	grid ${thisfield}_old_position -row $row -column 2 -sticky e
	grid ${thisfield}_new_position -row $row -column 3 -sticky e
	
	incr row
	
	#-----------------------------------------------------------
	
	label .main.blank1
	grid .main.blank1
	
	incr row
	
	label .main.slits -text Slits
	grid .main.slits -sticky w
	
	incr row

	set vert_slit [ $record_list get_record "bv_center" ]

	set thisfield .main.vert_slit

	button ${thisfield}_button -text "Optimize Vertical" -background limegreen -command \
	    [ code optimize_vert_slit $record_list $vert_slit $thisfield ]
	
	label ${thisfield}_status -width $statuswidth -text "Not Yet Optimized"
	
	label ${thisfield}_old_position -text \
		[ optimize_get_position $vert_slit ]

	label ${thisfield}_new_position -text "---"
	
	grid ${thisfield}_button       -row $row -column 0 -sticky w
	grid ${thisfield}_status       -row $row -column 1 -sticky w
	grid ${thisfield}_old_position -row $row -column 2 -sticky e
	grid ${thisfield}_new_position -row $row -column 3 -sticky e
	
	incr row
	
	set horiz_slit [ $record_list get_record "bh_center" ]

	set thisfield .main.horiz_slit
	
	button ${thisfield}_button -text "Optimize Horizontal" -background limegreen -command \
	    [ code optimize_horiz_slit $record_list $horiz_slit $thisfield ]
	
	label ${thisfield}_status -width $statuswidth -text "Not Yet Optimized"
	
	label ${thisfield}_old_position -text \
		[ optimize_get_position $horiz_slit ]

	label ${thisfield}_new_position -text "---"
	
	grid ${thisfield}_button       -row $row -column 0 -sticky w
	grid ${thisfield}_status       -row $row -column 1 -sticky w
	grid ${thisfield}_old_position -row $row -column 2 -sticky e
	grid ${thisfield}_new_position -row $row -column 3 -sticky e
	
	incr row
	
	#-----------------------------------------------------------
	
	frame .sep2 -height 2 -borderwidth 1 -relief sunken
	pack .sep2 -expand yes -fill x -pady 8 -before .message_log
	
	frame .bottom
	pack .bottom -before .message_log
	
	button .bottom.dismiss -text Dismiss -command exit
	pack .bottom.dismiss

	frame .sep3 -height 2 -borderwidth 1 -relief sunken
	pack .sep3 -expand yes -fill x -pady 8 -before .message_log
	
	wm deiconify .
}

proc optimize_omega { record_list motor guifield } {

	perform_optimization $record_list $motor $guifield
}

proc optimize_chi { record_list motor guifield } {

	perform_optimization $record_list $motor $guifield
}

proc optimize_horiz_slit { record_list motor guifield } {

	perform_optimization $record_list $motor $guifield
}

proc optimize_vert_slit { record_list motor guifield } {

	perform_optimization $record_list $motor $guifield
}

proc optimize_vert_mirror { record_list motor guifield } {

	perform_optimization $record_list $motor $guifield
}

