/* Computes the weighted mean of a dataset consisting of (x,y) pairs. */

#include <stdio.h>
#include <stdlib.h>
#include <math.h>

int
main( int argc, char **argv )
{
	char buffer[200];
	FILE *file;
	double x_value, y_value, y_sum, xy_sum, weighted_mean;
	int num_items;

	if ( argc != 2 ) {
		fprintf( stderr, "Usage: weighted_mean 'datafile'\n" );
		exit(1);
	}

	file = fopen( argv[1], "r" );

	if ( file == NULL ) {
		perror( argv[1] );
		exit(1);
	}

	/* Read the data file, computing the weighted mean as we go. */

	y_sum = 0.0;
	xy_sum = 0.0;

	fgets( buffer, sizeof(buffer), file );

	while ( !feof( file ) && !ferror( file ) ) {

		num_items = sscanf( buffer, "%lg %lg", &x_value, &y_value );

		if ( num_items != 2 ) {
			fprintf( stderr,
				"Did not find a data point in the line '%s'\n",
				buffer );
			exit(1);
		}

		y_sum += y_value;

		xy_sum += ( x_value * y_value );

		fgets( buffer, sizeof(buffer), file );
	}

	if ( fabs(y_sum) < 1.0e-30 ) {
		fprintf( stderr, "y_sum value %g is too small.\n", y_sum );
		exit(1);
	}

	weighted_mean = xy_sum / y_sum;

	printf( "%g\n", weighted_mean );

	exit(0);
}

